@@ -23,6 +23,7 @@ from typing import List, Optional, Union
 from qds_sdk.commands import Command
 
 from airflow.exceptions import AirflowException
+from airflow.hooks.dbapi import DbApiHook
 from airflow.providers.qubole.hooks.qubole import QuboleHook
 
 log = logging.getLogger(__name__)
@@ -74,7 +75,7 @@ def parse_first_row(row_list) -> List[Union[bool, float, int, str]]:
     return record_list
 
 
-class QuboleCheckHook(QuboleHook):
+class QuboleCheckHook(QuboleHook, DbApiHook):
     """Qubole check hook"""
 
     def __init__(self, context, *args, **kwargs) -> None:
@@ -98,7 +99,7 @@ class QuboleCheckHook(QuboleHook):
                     log.info('Cancelling the Qubole Command Id: %s', cmd_id)
                     cmd.cancel()
 
-    def get_first(self, sql):  # pylint: disable=unused-argument
+    def get_first(self, sql):
         """Get Qubole query first record list"""
         self.execute(context=self.context)
         query_result = self.get_query_results()
